@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,9 +20,31 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
-``rattail.console`` -- Console Stuff
+Console Stuff
 """
 
-from edbob.console import Progress
+from __future__ import unicode_literals
+
+import sys
+
+import progressbar
+
+
+class Progress(object):
+    """
+    Provides a console-based progress bar.
+    """
+
+    def __init__(self, message, maximum, stdout=None):
+        self.stdout = stdout or sys.stderr
+        self.stdout.write("\n{0}...({1} total)\n".format(message, maximum))
+        widgets = [progressbar.Percentage(), ' ', progressbar.Bar(), ' ', progressbar.ETA()]
+        self.progress = progressbar.ProgressBar(maxval=maximum, widgets=widgets).start()
+
+    def update(self, value):
+        self.progress.update(value)
+        return True
+
+    def destroy(self):
+        self.stdout.write("\n")
