@@ -20,11 +20,12 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 File Monitor Actions
 """
 
+from __future__ import unicode_literals
+
 import os
 import sys
 import time
@@ -79,6 +80,9 @@ def perform_actions(profile):
     stop = False
     while not stop:
 
+        # Suspend execution briefly, to avoid consuming so much CPU...
+        time.sleep(0.01)
+
         try:
             path = profile.queue.get_nowait()
         except Queue.Empty:
