@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,10 +20,11 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
+"""
+Global Product Code
+"""
 
-"""
-``rattail.gpc`` -- Global Product Code
-"""
+from __future__ import unicode_literals, absolute_import
 
 from rattail import barcodes
 
@@ -74,13 +74,20 @@ class GPC(object):
             return True
 
     def __cmp__(self, other):
-        if int(self) < int(other):
-            return -1
-        if int(self) > int(other):
+
+        # treat non-integers as being less than myself
+        try:
+            other = int(other)
+        except (TypeError, ValueError):
             return 1
-        if int(self) == int(other):
-            return 0
-        assert False
+
+        myself = int(self)
+        if myself < other:
+            return -1
+        if myself > other:
+            return 1
+        assert myself == other
+        return 0
 
     def __hash__(self):
         return hash(self.value)
@@ -99,3 +106,11 @@ class GPC(object):
 
     def __unicode__(self):
         return u'%014d' % self.value
+
+    def pretty(self):
+        """
+        Returns the UPC as a somewhat more human-readable string.  Basically
+        that just means the check digit is distinguished by a hyphen.
+        """
+        upc = unicode(self)
+        return "{0}-{1}".format(upc[:-1], upc[-1])
