@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,9 +20,8 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
-``rattail.sil`` -- Standard Interchange Language
+Standard Interchange Language
 
 Please see the `Standard Interchange Language Specifications
 <http://productcatalog.gs1us.org/Store/tabid/86/CategoryID/21/List/1/catpageindex/2/Level/a/ProductID/46/Default.aspx>`_
@@ -31,5 +29,5 @@ for more information.
 """
 
 from rattail.sil.columns import *
-from rattail.sil.batches import *
+from .batches import consume_batch_id
 from rattail.sil.writer import *
